@@ -1,6 +1,8 @@
 /* ***** BEGIN LICENSE BLOCK *****
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
+ * Copyright (C) 2002-2022 Németh László
+ *
  * The contents of this file are subject to the Mozilla Public License Version
  * 1.1 (the "License"); you may not use this file except in compliance with
  * the License. You may obtain a copy of the License at
@@ -11,12 +13,7 @@
  * for the specific language governing rights and limitations under the
  * License.
  *
- * The Original Code is Hunspell, based on MySpell.
- *
- * The Initial Developers of the Original Code are
- * Kevin Hendricks (MySpell) and Németh László (Hunspell).
- * Portions created by the Initial Developers are Copyright (C) 2002-2005
- * the Initial Developers. All Rights Reserved.
+ * Hunspell is based on MySpell which is Copyright (C) 2002 Kevin Hendricks.
  *
  * Contributor(s): David Einstein, Davide Prina, Giuseppe Modugno,
  * Gianluca Turconi, Simon Brouwer, Noll János, Bíró Árpád,
@@ -42,7 +39,7 @@
 #include <cstdlib>
 #include <cstdio>
 
-#include "hunspell.hxx"
+#include "../hunspell/hunspell.hxx"
 
 #ifndef WIN32
 using namespace std;
@@ -77,29 +74,24 @@ int main(int, char** argv) {
     char* s = strchr(buf, ' ');
     if (s) {
       *s = '\0';
-      char** result;
-      int n = pMS->generate(&result, buf, s + 1);
-      for (int i = 0; i < n; i++) {
-        fprintf(stdout, "generate(%s, %s) = %s\n", buf, s + 1, result[i]);
+      std::vector<std::string> result = pMS->generate(buf, s + 1);
+      for (size_t i = 0; i < result.size(); ++i) {
+        fprintf(stdout, "generate(%s, %s) = %s\n", buf, s + 1, result[i].c_str());
       }
-      pMS->free_list(&result, n);
-      if (n == 0)
+      if (result.empty())
         fprintf(stdout, "generate(%s, %s) = NO DATA\n", buf, s + 1);
     } else {
-      int dp = pMS->spell(buf);
+      int dp = pMS->spell(std::string(buf));
       fprintf(stdout, "> %s\n", buf);
       if (dp) {
-        char** result;
-        int n = pMS->analyze(&result, buf);
-        for (int i = 0; i < n; i++) {
-          fprintf(stdout, "analyze(%s) = %s\n", buf, result[i]);
+        std::vector<std::string> result = pMS->analyze(buf);
+        for (size_t i = 0; i < result.size(); ++i) {
+          fprintf(stdout, "analyze(%s) = %s\n", buf, result[i].c_str());
         }
-        pMS->free_list(&result, n);
-        n = pMS->stem(&result, buf);
-        for (int i = 0; i < n; i++) {
-          fprintf(stdout, "stem(%s) = %s\n", buf, result[i]);
+        result = pMS->stem(buf);
+        for (size_t i = 0; i < result.size(); ++i) {
+          fprintf(stdout, "stem(%s) = %s\n", buf, result[i].c_str());
         }
-        pMS->free_list(&result, n);
       } else {
         fprintf(stdout, "Unknown word.\n");
       }
